pub struct Executor<S> { /* private fields */ }Expand description
A Beetry executor parameterized by its lifecycle state.
Implementations
Sourceimpl Executor<Init>
impl Executor<Init>
Sourcepub fn new(config: ExecutorConfig) -> Executor<WithRegistry>
pub fn new(config: ExecutorConfig) -> Executor<WithRegistry>
Creates a new executor with an internal bounded task channel.
The returned executor is still in its setup phase.
Sourceimpl Executor<WithRegistry>
impl Executor<WithRegistry>
Sourcepub fn into_ready_with_registry(self) -> (Executor<Ready>, TaskRegistry)
pub fn into_ready_with_registry(self) -> (Executor<Ready>, TaskRegistry)
Finalizes setup and returns both the runnable executor and its registry.
This is the transition point between initialization and runtime:
- the returned
Executor<Ready>can be driven withExecutorConcept::run - the returned
TaskRegistrycan be shared with code that needs to scheduleActionTaskvalues